@@ -201,6 +201,22 @@ pub fn axial_to_cubic(node_coords: (i32, i32)) -> (i32, i32, i32) {
 	let y = -z - x;
 	(x, y, z)
 }
+/// Convert a node with Axial coordinates to Offset coordinates based on an orientation. `node_coords` is of the form
+/// `(q, r)` where `q` is the column and `r` the row
+pub fn axial_to_offset(node_coords: (i32, i32), orientation: &HexOrientation) -> (i32, i32) {
+	match orientation {
+		HexOrientation::FlatTopOddUp => {
+			let x: i32 = node_coords.0;
+			let y: i32 = node_coords.1 + (node_coords.0 + (node_coords.0 & 1)) / 2;
+			(x, y)
+		}
+		HexOrientation::FlatTopOddDown => {
+			let x: i32 = node_coords.0;
+			let y: i32 = node_coords.1 + (node_coords.0 - (node_coords.0 & 1)) / 2;
+			(x, y)
+		}
+	}
+}
 /// Convert a node with Cubic coordinates to Axial coordinates. `node_coords` is of the form
 /// `(x, y, z)`.
 pub fn cubic_to_axial(node_coords: (i32, i32, i32)) -> (i32, i32) {
@@ -208,6 +224,22 @@ pub fn cubic_to_axial(node_coords: (i32, i32, i32)) -> (i32, i32) {
 	let r = node_coords.2;
 	(q, r)
 }
+/// Convert a node with Cubic coordinates to Offset coordinates based on an orientation. `node_coords` is of the form
+/// `(x, y, z)`.
+pub fn cubic_to_offset(node_coords: (i32, i32, i32), orientation: &HexOrientation) -> (i32, i32) {
+	match orientation {
+		HexOrientation::FlatTopOddUp => {
+			let x: i32 = node_coords.0;
+			let y: i32 = node_coords.2 + (node_coords.0 + (node_coords.0 & 1)) / 2;
+			(x, y)
+		}
+		HexOrientation::FlatTopOddDown => {
+			let x: i32 = node_coords.0;
+			let y: i32 = node_coords.2 + (node_coords.0 - (node_coords.0 & 1)) / 2;
+			(x, y)
+		}
+	}
+}
 /// Finds the neighboring nodes in an Offset coordinate system. It must be in a grid-like formatiom
 ///  where 'min_column`,`max_column` `min_row` and `max_row` inputs define the outer boundary of the grid space, note they
 /// are exclusive values. This means that for most source hexagons 6 neighbours will be expanded but
@@ -358,10 +390,11 @@ pub fn node_neighbours_offset(
 	neighbours
 }
 /// Finds the neighboring nodes in a Cubic coordinate system. `source` is of the form
-/// `(x, y, z)`. The node grid is in a circular arrangement with `count_rings_from_origin` being
-/// the number of rings around the origin of the grid - the value is inclusive.
+/// `(x, y, z)` and denotes the node from which neighbours are discovered. The node grid is in a
+/// circular arrangement with `count_rings_from_origin` being the number of rings around the origin
+/// of the entire grid, this prevents returning theoretical nodes which exist outside of the grid - the value is inclusive.
 ///
-/// For instance:
+/// For instance if the entire grid is:
 /// ```txt
 ///              _______
 ///             /   0   \
@@ -377,38 +410,14 @@ pub fn node_neighbours_offset(
 ///            \ -1    1 /
 ///             \_______/
 /// ```
-/// Will have a `count_rings_from_origin` of 1.
+/// Will have a `count_rings_from_origin` of 1 preventing returning non existent nodes.
 #[allow(clippy::int_plus_one)]
 pub fn node_neighbours_cubic(
 	source: (i32, i32, i32),
 	count_rings_from_origin: i32,
 ) -> Vec<(i32, i32, i32)> {
-	let mut neighbours = Vec::new();
-	// north (x, y + 1, z - 1)
-	if source.1 + 1 <= count_rings_from_origin && (source.2 - 1).abs() <= count_rings_from_origin {
-		neighbours.push((source.0, source.1 + 1, source.2 - 1))
-	}
-	// north-east (x + 1, y, z - 1)
-	if source.0 + 1 <= count_rings_from_origin && (source.2 - 1).abs() <= count_rings_from_origin {
-		neighbours.push((source.0 + 1, source.1, source.2 - 1))
-	}
-	// south-east (x + 1, y - 1, z)
-	if source.0 + 1 <= count_rings_from_origin && (source.1 - 1).abs() <= count_rings_from_origin {
-		neighbours.push((source.0 + 1, source.1 - 1, source.2))
-	}
-	// south (x, y - 1, z + 1)
-	if (source.1 - 1).abs() <= count_rings_from_origin && source.2 + 1 <= count_rings_from_origin {
-		neighbours.push((source.0, source.1 - 1, source.2 + 1))
-	}
-	// south-west (x - 1, y, z + 1)
-	if (source.0 - 1).abs() <= count_rings_from_origin && source.2 + 1 <= count_rings_from_origin {
-		neighbours.push((source.0 - 1, source.1, source.2 + 1))
-	}
-	// north-west (x - 1, y + 1, z)
-	if (source.0 - 1).abs() <= count_rings_from_origin && source.1 + 1 <= count_rings_from_origin {
-		neighbours.push((source.0 - 1, source.1 + 1, source.2))
-	}
-	neighbours
+	// the neighbours are on the first ring hence we hardcode the ring_number
+	node_ring_cubic(source, 1, count_rings_from_origin)
 }
 /// Finds the neighboring nodes in an Axial coordinate system. `source` is of the form
 /// `(q, r)` where `q` is the column and `r` the row. The node grid is in a circular arrangment
@@ -442,6 +451,73 @@ pub fn node_neighbours_axial(source: (i32, i32), count_rings_from_origin: i32) -
 	}
 	neighbours
 }
+/// Finds the nodes on a ring around a given source point in a Cubic coordinate system. `source` is of the form
+/// `(x, y, z)`. The node grid is in a circular arrangement with `count_rings_from_origin` being
+/// the number of rings around the origin of the entire grid, this prevents returning nodes which exist outside of the
+/// grid - the value is inclusive. 'ring_number' is the particular ring you want to know the nodes of
+///
+/// For instance:
+/// ```txt
+///              _______
+///             /   0   \
+///     _______/         \_______
+///    /  -1   \ 1    -1 /   1   \
+///   /         \_______/         \
+///   \ 1     0 /   x   \ 0    -1 /
+///    \_______/         \_______/
+///    /  -1   \ y     z /   1   \
+///   /         \_______/         \
+///   \ 0     1 /   0   \ -1    0 /
+///    \_______/         \_______/
+///            \ -1    1 /
+///             \_______/
+/// ```
+/// With a `ring_number = 1` will find the immediate neighbouring nodes around the centre
+#[allow(clippy::int_plus_one)]
+pub fn node_ring_cubic(
+	source: (i32, i32, i32),
+	ring_number: i32,
+	count_rings_from_origin: i32,
+) -> Vec<(i32, i32, i32)> {
+	let mut neighbours = Vec::new();
+	// north (x, y + ring_number, z - ring_number)
+	if (source.1 + ring_number).abs() <= count_rings_from_origin
+		&& (source.2 - ring_number).abs() <= count_rings_from_origin
+	{
+		neighbours.push((source.0, source.1 + ring_number, source.2 - ring_number))
+	}
+	// north-east (x + ring_number, y, z - ring_number)
+	if (source.0 + ring_number).abs() <= count_rings_from_origin
+		&& (source.2 - ring_number).abs() <= count_rings_from_origin
+	{
+		neighbours.push((source.0 + ring_number, source.1, source.2 - ring_number))
+	}
+	// south-east (x + ring_number, y - ring_number, z)
+	if (source.0 + ring_number).abs() <= count_rings_from_origin
+		&& (source.1 - ring_number).abs() <= count_rings_from_origin
+	{
+		neighbours.push((source.0 + ring_number, source.1 - ring_number, source.2))
+	}
+	// south (x, y - ring_number, z + ring_number)
+	if (source.1 - ring_number).abs() <= count_rings_from_origin
+		&& (source.2 + ring_number).abs() <= count_rings_from_origin
+	{
+		neighbours.push((source.0, source.1 - ring_number, source.2 + ring_number))
+	}
+	// south-west (x - ring_number, y, z + ring_number)
+	if (source.0 - ring_number).abs() <= count_rings_from_origin
+		&& (source.2 + ring_number).abs() <= count_rings_from_origin
+	{
+		neighbours.push((source.0 - ring_number, source.1, source.2 + ring_number))
+	}
+	// north-west (x - ring_number, y + ring_number, z)
+	if (source.0 - ring_number).abs() <= count_rings_from_origin
+		&& (source.1 + ring_number).abs() <= count_rings_from_origin
+	{
+		neighbours.push((source.0 - ring_number, source.1 + ring_number, source.2))
+	}
+	neighbours
+}
 
 /// The distance between two nodes by using cubic coordinates
 pub fn node_distance(start: (i32, i32, i32), end: (i32, i32, i32)) -> i32 {
@@ -709,4 +785,36 @@ mod tests {
 		let actual = vec![(2, 0, -2), (2, -2, 0), (1, -1, 0), (1, 0, -1)];
 		assert_eq!(actual, neighbours);
 	}
+	#[test]
+	/// convert axial coords to offset in a FlatTopOddUp grid orienation
+	fn convert_axial_to_offset_odd_up() {
+		let source: (i32, i32) = (-1, -1);
+		let result = axial_to_offset(source, &HexOrientation::FlatTopOddUp);
+		let actual: (i32, i32) = (-1, -1);
+		assert_eq!(actual, result);
+	}
+	#[test]
+	/// convert axial coords to offset in a FlatTopOddDown grid orienation
+	fn convert_axial_to_offset_odd_down() {
+		let source: (i32, i32) = (-1, -1);
+		let result = axial_to_offset(source, &HexOrientation::FlatTopOddDown);
+		let actual: (i32, i32) = (-1, -2);
+		assert_eq!(actual, result);
+	}
+	#[test]
+	/// convert cubic coords to offset in a FlatTopOddUp grid orientation
+	fn convert_cubic_to_offset_odd_up() {
+		let source: (i32, i32, i32) = (-2, 3, -1);
+		let result = cubic_to_offset(source, &HexOrientation::FlatTopOddUp);
+		let actual: (i32, i32) = (-2, -2);
+		assert_eq!(actual, result);
+	}
+	#[test]
+	/// convert cubic coords to offset in a FlatTopOddDown grid orientation
+	fn convert_cubic_to_offset_odd_downp() {
+		let source: (i32, i32, i32) = (-1, 1, 0);
+		let result = cubic_to_offset(source, &HexOrientation::FlatTopOddDown);
+		let actual: (i32, i32) = (-1, -1);
+		assert_eq!(actual, result);
+	}
 }
